@@ -2,9 +2,9 @@
 /*! \file cdhashset_forward.h
  ** \verbatim
  ** Top contributors (to current version):
- **   Morgan Deters, Paul Meng, Dejan Jovanovic
+ **   Morgan Deters, Tim King, Dejan Jovanovic
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2017 by the authors listed in the file AUTHORS
+ ** Copyright (c) 2009-2018 by the authors listed in the file AUTHORS
  ** in the top-level source directory) and their institutional affiliations.
  ** All rights reserved.  See the file COPYING in the top-level source
  ** directory for licensing information.\endverbatim
@@ -26,19 +26,13 @@
 #ifndef __CVC4__CONTEXT__CDSET_FORWARD_H
 #define __CVC4__CONTEXT__CDSET_FORWARD_H
 
-/// \cond internals
-
-namespace __gnu_cxx {
-  template <class Key> struct hash;
-}/* __gnu_cxx namespace */
+#include <functional>
 
 namespace CVC4 {
-  namespace context {
-    template <class V, class HashFcn = __gnu_cxx::hash<V> >
-    class CDHashSet;
-  }/* CVC4::context namespace */
-}/* CVC4 namespace */
-
-/// \endcond
+namespace context {
+template <class V, class HashFcn = std::hash<V> >
+class CDHashSet;
+}  // namespace context
+}  // namespace CVC4
 
 #endif /* __CVC4__CONTEXT__CDSET_FORWARD_H */
